@@ -85,6 +85,13 @@ class ChartController < ApplicationController
 
   private
 
+  def y_range(total, completed)
+    max_total = total.max + 5
+    min_completed = ((completed.min - 1) / 5 * 5)
+    min_completed = 0 if min_completed < 0
+    return min_completed, max_total
+  end
+
   def burn_up_data(project_id)
     if @user.is_trivial_use
       workloads = CompletedWorkloads.where(project_id: project_id).order("date DESC")
@@ -117,7 +124,6 @@ class ChartController < ApplicationController
     completed = []
     last_total = nil
     last_completed = nil
-    max_total = 0
     day = workloads.last.date
 
     while day <= Date.today do
@@ -136,13 +142,13 @@ class ChartController < ApplicationController
       total << last_total
       completed << last_completed
 
-      max_total = last_total if not last_total.nil? and (last_total > max_total)
-
       day += 1
     end
-    max_total += 5
 
-    if total.size < PastDays
+    if total.size <= PastDays
+      # 表示するデータにおける最大値、最小値を得る
+      min_completed, max_total = y_range(total, completed)
+
       add_size = PastDays - total.size
       # 空の領域をデータの先頭に追加する
       total = Array.new(add_size, nil) + total
@@ -156,9 +162,12 @@ class ChartController < ApplicationController
       raw_date = add_date + raw_date
     elsif total.size > PastDays
       # 表示しない範囲のデータを切り捨てる
-      total = total[-PastDays, PastDays]
+      total = total[-PastDays , PastDays]
       completed = completed[-PastDays, PastDays]
       raw_date = raw_date[-PastDays, PastDays]
+
+      # 表示するデータにおける最大値、最小値を得る
+      min_completed, max_total = y_range(total, completed)
     end
 
     FutureDays.times do
@@ -166,7 +175,7 @@ class ChartController < ApplicationController
       day += 1
     end
 
-    return raw_date, total, completed, 0, max_total
+    return raw_date, total, completed, min_completed, max_total
   end
 
   def wday_color(date)
